package ru.dbotthepony.mc.otm.menu.widget;

import com.mojang.blaze3d.systems.RenderSystem;
import com.mojang.blaze3d.vertex.PoseStack;
import net.minecraft.client.renderer.GameRenderer;
import ru.dbotthepony.mc.otm.menu.MatteryMenu;
import ru.dbotthepony.mc.otm.screen.MatteryScreen;

abstract public class GaugeWidget<T extends MatteryMenu> extends AbstractWidget<T> {
	public enum GaugeDirection {
		TOP_TO_BOTTOM,
		BOTTOM_TO_TOP,
		LEFT_TO_RIGHT,
		RIGHT_TO_LEFT
	}

	public GaugeWidget(T menu, int x, int y) {
		super(menu, x, y);
	}

	public GaugeDirection fill_order = GaugeDirection.BOTTOM_TO_TOP;

	abstract public float getLevel();

	protected void setupGaugeDrawing() {
		RenderSystem.setShader(GameRenderer::getPositionTexShader);
		RenderSystem.setShaderColor(1.0F, 1.0F, 1.0F, 1.0F);
		RenderSystem.setShaderTexture(0, TEXTURE);
	}

	@Override
	public void renderBackground(MatteryScreen<T> screen, PoseStack pose, int local_x, int local_y, int mouse_x, int mouse_y) {
		setupGaugeDrawing();

		screen.blit(pose, local_x + x, local_y + y, getImageX(), getImageY(), getImageWidth(), getImageHeight());
		float level = getLevel();

		if (level > 0.01f) {


			if (fill_order == GaugeDirection.BOTTOM_TO_TOP) {
				int intHeight = (int) Math.floor(level * (float) getImageHeight() + 0.5f);

				screen.blit(
					pose,
					local_x + x,
					local_y + y + getImageHeight() - intHeight,
					getImageX() + getImageWidth(),
					getImageY() + getImageHeight() - intHeight,
					getImageWidth(),
					intHeight);
			} else if (fill_order == GaugeDirection.TOP_TO_BOTTOM) {
				screen.blit(
					pose,
					local_x + x,
					local_y + y,
					getImageX() + getImageWidth(),
					getImageY(),
					getImageWidth(),
					(int) Math.floor(level * (float) getImageHeight() + 0.5f));
			} else if (fill_order == GaugeDirection.LEFT_TO_RIGHT) {
				screen.blit(
					pose,
					local_x + x,
					local_y + y,
					getImageX() + getImageWidth(),
					getImageY(),
					(int) Math.floor(level * (float) getImageWidth() + 0.5f),
					getImageHeight());
			}
		}
	}
}
